@@ -5,6 +5,8 @@ if (! $this->CheckPermission('Use MetaMax')) {
   return $this->DisplayErrorPage($id, $params, $returnid,$this->Lang('accessdenied'));
 }
 
+$this->SetPreference('keywordson_title',
+		     (isset($params['keywordson_title'])?'1':'0'));
 $this->SetPreference('key_number', $params['key_number']);
 $this->SetPreference('key_length', $params['key_length']);
 $this->SetPreference('key_density', $params['key_density']);
