@@ -192,8 +192,9 @@ $lang['analytics_single'] = 'A single domain';
 $lang['analytics_sub'] = 'One domain with multiple subdomains';
 $lang['analytics_multiple'] = 'Multiple top-level domains';
 $lang['analytics_universal'] = 'Universal Analytics';
-$lang['analytics_help'] = 'If Universal Analytics is chosen Advertiser support option will be ignored';
-$lang['analytics_support'] = 'Display Advertiser Support';
+$lang['analytics_help'] = 'If Universal Analytics is chosen Advertiser support and enhanced link attribution options will be ignored';
+$lang['analytics_support'] = 'Display Advertiser Support/Demographics and Interest reports tag?';
+$lang['analytics_enhanced_link'] = 'Include enhanced link attribution tag?';
 $lang['propertyid_title'] = 'Web Property ID (ie UA-XXXXXXXX-1)';
 $lang['webmasterid_title'] = 'Webmaster meta verification key';
 $lang['pretty_title'] = 'Are pretty URLs enabled?';
@@ -253,7 +254,9 @@ $lang['changelog'] = '<ul>
 <li>Version 1.9.9 30 April 2013. Added the ability to disable/enable keywords tag.</li>
 <li>Version 1.9.9.1 2 May 2013. Minor bug fixes.</li>
 <li>Version 1.9.9.2 25 June 2013. Stripped files appended with thumb_ from image dropdowns. Added process_pagedata tag to MetaMax output, making the Meta Data field redundant.</li>
-<li>Version 1.9.9.3 30 July 2013. Added trailing slash option for base tag, plus minor language updates spotted by Velden.</li></ul>';
+<li>Version 1.9.9.3 30 July 2013. Added trailing slash option for base tag, plus minor language updates spotted by Velden.</li>
+<li>Version 1.9.9.4 11 November 2013. Added option to include Demographics and Interest Reports tag into Analytics code.</li>
+<li>Version 1.9.9.5 20 November 2013. Added option to include enhanced link attribution tag into Analytics code.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
